pro get_annotes, infilename, sds_name, descriptions,valid_values

;+
;.......................................................................
; $Id$
;.......................................................................
; NAME: get_annotes
;	
;
; PURPOSE:
;        Reads the valid range, and the description for each valid value.
;	
;
; CATEGORY:
;        HDF data reader
;
;
; CALLING SEQUENCE:
;	get_annotes, infilename, sds_name, descriptions, valid_range
;
; INPUTS:
;	infilename  :	The file name of a sample input file.
;       sds_name    : 	The sds to read the valids for.
;
; OUTPUTS:
;       descriptions:	The descriptions for each valid value.
;       valid_range :	The range of valid values.
;
; SIDE EFFECTS:
;       None.
;.......................................................................
; REVISION HISTORY:
;      11/08/2001	EGM     Add routine to read in all of the descriptors.
;       3/07/2000	MAG	Updates with proper MODIS names and additional
;                       code to take into account incorrectly set FillValues
;                       in the L-1B data itself. 
;.......................................................................
; PROGRAMMER:  
; 	       Eric G Moody (moody@climate.gsfc.nasa.gov)
;
;              Mark A Gray (gray@climate.gsfc.nasa.gov
;              Jason Li 
;              SM&A Inc | Climate and Radiation Branch
;              NASA Goddard Space Flight Center
;              Greenbelt, Maryland, U.S.A.
;.......................................................................
.......................................................................
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;.......................................................................
;-

;-

;Open the file and get the fileID:
fileID = HDF_SD_START(infilename,/READ)


;Select the SDS:
index = HDF_SD_NAMETOINDEX(fileID,sds_name)
sdsid = HDF_SD_SELECT(fileID, index)


;Read in the valid range:
valID = HDF_SD_ATTRFIND(sdsid,'valid_values')
if valID NE -1 THEN BEGIN
   HDF_SD_ATTRINFO, sdsid, valID, DATA = valid_values
endif


;Determine the number of valid values, and thus the number of descripters:
numValids = size(valid_values)
numValids = numValids[1]


;Get the descriptors:
descriptions = strarr(numValids)
des_num = 0
for icnt = valid_values[0], valid_values[numValids-1] do begin
    stricnt = string(icnt)
    attrName = 'annot_value_'+strcompress(stricnt,/REMOVE_ALL)
    desID = HDF_SD_ATTRFIND(sdsid,attrName)
    if desID NE -1 THEN BEGIN
       HDF_SD_ATTRINFO, sdsid, desID, DATA = descript
       descriptions[des_num] = descript
    endif
    des_num = des_num + 1
endfor


;End access to the SDS:
HDF_SD_ENDACCESS, sdsid


;Close the file:
HDF_SD_END, fileId


end
