pro ApplyColorCurve,curvename,image

;*************************************************************************
; Name: l1b
;
; Purpose:
;   this code reads a photoshop curve and returns the color correction curves
;
; Inputs:
;  curvename:  The photoshop color curve to apply
;
; Outputs:
;  image:      The color corrected image.
;
; Required programs:
;  none.
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Mark A. Gray
;  gray@climate.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
; it freely, subject to the following restrictions:
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



openu,lun,curvename,/get_lun
curvetemp=bytarr(1024)
readu,lun,curvetemp


allcurves=bytarr(3,256)

;allcurves[0,*]=curvetemp[256:511]
;allcurves[1,*]=curvetemp[512:767]
;allcurves[2,*]=curvetemp[768:1023]


allcurves[0,*]=curvetemp[0:255]
allcurves[1,*]=curvetemp[0:255]
allcurves[2,*]=curvetemp[0:255]

dummy=size(image)
if dummy[0] eq 3 then begin
 ; 3 color truecolor imagery
 xsize=dummy[1]
 ysize=dummy[2]
 zsize=dummy[3]
 temparr=bytarr(xsize,ysize,zsize)
endif

if dummy[0] eq 2 then begin
 xsize=dummy[1]
 ysize=dummy[2]
 zsize=0
 temparr=bytarr(xsize,ysize)
endif



;for colorchannel=0,zsize-1 do begin

  colorchannel=0 

  for i=0,255 do begin

    colorindex=byte(i) 
    temp=where(image eq colorindex,count)

    if count gt 0 then temparr[temp]=allcurves[colorchannel,i] 

  endfor
;endfor

image=temparr


end
