PRO l1b

;*************************************************************************
; Name: l1b
;
; Purpose:
;   This rountine is the main driver to plot the l1b RGB true color composite.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   Input_Path     :  Directory where the L2 file is stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_l1b.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
; it freely, subject to the following restrictions:
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;*************************************************************************
;  Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names.
;*************************************************************************
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')


;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')


;*************************************************************************
; Define the files that contain the Ancillary data, including path.  
;*************************************************************************
;Define the overall path where the files reside:
MOD021KMPath = GETENV('Input_Path')

;Define the MOD021KM File Name:
file_spec = MOD021KMPath+'MOD021KM*'+ Year + Day + '.' + Time + '*' 
result = FINDFILE(file_spec)
MOD021KMfilename = strcompress(result(0))



;*************************************************************************
; End of definition section, make changes to the rest of the code at
; your own discretion.  If you wish to define a lat/lon box to plot,
; define it in the section below and choose the program call which
; includes the limits in the call.
;*************************************************************************




   ;*************************************************************************
   ; Define the name of the output image file, including path:
   ;*************************************************************************
   OutFileName = output_dir+'L1B.143.'+Year+'.'+Day+'.'+Time+'.tiff'

   ;*************************************************************************
   ; Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   titlestring = 'L1B True-Color Composite, Bands 1,4,3, Julian Day '+Day+', '+Year+' '+Time+' UTC'



   ;*************************************************************************
   ;Call the program:
   ;*************************************************************************
   plot_l1b, MOD021KMfilename, OutFileName, titlestring



END
